@@ -5,7 +5,7 @@ require Test::Harness;
 
 sub BaseTests {
 
-    my $CLASS = shift;
+    my ($CLASS, $no_qv) = @_;
     
     # Insert your test code below, the Test module is use()ed here so read
     # its man page ( perldoc Test ) for help writing this test script.
@@ -203,13 +203,17 @@ sub BaseTests {
     ok ( !eval { $version*3 }, "noop *" );
     ok ( !eval { abs($version) }, "noop abs" );
 
+SKIP: {
+    skip "version require'd instead of use'd, cannot test qv", 3
+    	if defined $no_qv;
     # test the qv() sub
     diag "testing qv" if $Verbose;
     $version = qv("1.2");
-    ok ( $version eq "1.2.0", 'qv("1.2") eq "1.2.0"' );
+    cmp_ok ( $version, "eq", "v1.2.0", 'qv("1.2") eq "1.2.0"' );
     $version = qv(1.2);
-    ok ( $version eq "1.2.0", 'qv(1.2) eq "1.2.0"' );
+    cmp_ok ( $version, "eq", "v1.2.0", 'qv(1.2) eq "1.2.0"' );
     isa_ok( qv('5.008'), $CLASS );
+}
 
     # test creation from existing version object
     diag "create new from existing version" if $Verbose;
@@ -245,6 +249,10 @@ sub BaseTests {
     unlike($@, qr/Test::More version $version/,
 	    'Replacement eval works with exact version');
     
+    # test as class method
+    $new_version = Test::More->VERSION;
+    cmp_ok($new_version,'cmp',$version, "Called as class method");
+
     # this should fail even with old UNIVERSAL::VERSION
     $version = $Test::More::VERSION+0.01;
     eval "use Test::More $version";
@@ -277,6 +285,10 @@ sub BaseTests {
 	eval "use lib '.'; use xxx 3;";
 	like ($@, qr/$error_regex/,
 	    'Replacement handles modules without package or VERSION'); 
+	eval "use lib '.'; use xxx; $version = xxx->VERSION";
+	unlike ($@, qr/$error_regex/,
+	    'Replacement handles modules without package or VERSION'); 
+	isnt (defined($version), "Called as class method");
 	unlink 'xxx.pm';
     }
     
@@ -287,11 +299,27 @@ sub BaseTests {
 	eval "use lib '.'; use yyy 3;";
 	like ($@, qr/^yyy does not define \$yyy::VERSION/,
 	    'Replacement handles modules without VERSION'); 
+	eval "use lib '.'; use yyy; print yyy->VERSION";
+	unlike ($@, qr/^yyy does not define \$yyy::VERSION/,
+	    'Replacement handles modules without VERSION'); 
 	unlink 'yyy.pm';
     }
 
+    { # dummy up some variously broken modules for testing
+	open F, ">zzz.pm" or die "Cannot open zzz.pm: $!\n";
+	print F "package zzz;\n\@VERSION = ();\n1;\n";
+	close F;
+	eval "use lib '.'; use zzz 3;";
+	like ($@, qr/^zzz does not define \$zzz::VERSION/,
+	    'Replacement handles modules without VERSION'); 
+	eval "use lib '.'; use zzz; print zzz->VERSION";
+	unlike ($@, qr/^zzz does not define \$zzz::VERSION/,
+	    'Replacement handles modules without VERSION'); 
+	unlink 'zzz.pm';
+    }
+
 SKIP: 	{
-	skip 'Cannot test v-strings with Perl < 5.8.1', 4
+	skip 'Cannot test bare v-strings with Perl < 5.8.1', 4
 		if $] < 5.008_001; 
 	diag "Tests with v-strings" if $Verbose;
 	$version = $CLASS->new(1.2.3);
@@ -300,6 +328,8 @@ SKIP: 	{
 	$new_version = $CLASS->new(1);
 	ok($version == $new_version, '$version == $new_version');
 	ok($version eq $new_version, '$version eq $new_version');
+	skip "version require'd instead of use'd, cannot test qv", 1
+	    if defined $no_qv;
 	$version = qv(1.2.3);
 	ok("$version" eq "v1.2.3", 'v-string initialized qv()');
     }
@@ -324,9 +354,36 @@ SKIP: 	{
     $version = $CLASS->new(" 1.7");
     ok($version->numify eq "1.700", "leading space ignored");
 
+SKIP: {
+	$DB::single = 1;
+
+	# dummy up a legal module for testing RT#19017
+	open F, ">www.pm" or die "Cannot open www.pm: $!\n";
+	print F <<"EOF";
+package www;
+use version; \$VERSION = qv('0.0.4');
+1;
+EOF
+	close F;
+
+	eval "use lib '.'; use www 0.000008;";
+	like ($@, qr/^www version 0.000008 \(v0.0.8\) required/,
+	    "Make sure very small versions don't freak"); 
+	eval "use lib '.'; use www 1;";
+	like ($@, qr/^www version 1.000 \(v1.0.0\) required/,
+	    "Comparing vs. version with no decimal"); 
+	eval "use lib '.'; use www 1.;";
+	like ($@, qr/^www version 1.000 \(v1.0.0\) required/,
+	    "Comparing "); 
+
+	skip 'Cannot "use" extended versions with Perl < 5.6.2', 1
+	    if $] < 5.006_002;
+	eval "use lib '.'; use www 0.0.8;";
+	like ($@, qr/^www version 0.000008 \(v0.0.8\) required/,
+	    "Make sure very small versions don't freak"); 
+
+	unlink 'www.pm';
+    }
 }
 
-package known::module;
-# Look Ma!  No $VERSION;
-
 1;
