@@ -2,15 +2,10 @@
 package version::vpp;
 use strict;
 
-use Exporter ();
 use Scalar::Util;
-use vars qw ($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS @REGEXS);
-$VERSION     = 0.59;
-@ISA         = qw (Exporter);
-#Give a hoot don't pollute, do not export more than needed by default
-@EXPORT      = qw (qv);
-@EXPORT_OK   = qw ();
-%EXPORT_TAGS = ();
+use vars qw ($VERSION @ISA @REGEXS);
+$VERSION     = "0.60";
+$VERSION     = eval $VERSION;
 
 push @REGEXS, qr/
 	^v?	# optional leading 'v'
@@ -39,6 +34,18 @@ sub new
 	if ( !$@ and $eval ) {
 	    $value = sprintf("v%vd",$value);
 	}
+
+	# may be a non-magic v-string
+	if ( $] >= 5.006_002 && $] < 5.008_001
+		&& length($value) >= 3 && $value !~ /[._]/ ) {
+	    $DB::single = 1;
+	    my $tvalue = sprintf("%vd",$value);
+	    if ( $tvalue =~ /^\d+\.\d+\.\d+$/ ) {
+		# must be a non-magic v-string
+		$value = $tvalue;
+	    }
+	}
+	    
 	
 	# This is not very efficient, but it is morally equivalent
 	# to the XS code (as that is the reference implementation).
@@ -364,6 +371,11 @@ sub is_alpha {
 sub qv {
     my ($value) = @_;
 
+    if ( $value =~ /\d+e-?\d+/ ) { # exponential notation
+	$value = sprintf("%.9f",$value);
+	$value =~ s/(0+)//;
+    }
+
     my $eval = eval 'Scalar::Util::isvstring($value)';
     if ( !$@ and $eval ) {
 	$value = sprintf("v%vd",$value);
@@ -393,28 +405,44 @@ sub _verify {
     *UNIVERSAL::VERSION = sub {
 	my ($obj, $req) = @_;
 	my $class = ref($obj) || $obj;
+	if ( $req =~ /\d+e-?\d+/ ) { # exponential notation
+	    $req = sprintf("%.9f",$req);
+	    $req =~ s/(0+)$//;
+	}
 	no strict 'refs';
 	eval "require $class" unless %{"$class\::"}; # already existing
 	die "$class defines neither package nor VERSION--version check failed"
 	    if $@ or not %{"$class\::"};
 	
 	my $version = eval "\$$class\::VERSION";
-	die "$class does not define \$$class\::VERSION--version check failed"
-	    unless defined $version;
-
-	$version = version::vpp->new($version);
-
-	if ( defined $req ) {
-	    $req = version::vpp->new($req);
-
-	    die sprintf ("%s version %s (%s) required--".
-		     "this is only version %s (%s)", $class, 
-		     $req->numify, $req->normal,
-		     $version->numify, $version->normal)
-		if ( $req > $version ); 
+	if ( defined $version ) {
+	    $version = version::vpp->new($version);
 	}
 
-	return $version->numify;
+	if ( defined $req ) {
+	    unless ( defined $version ) {
+		my $msg =  "$class does not define ".
+			   "\$$class\::VERSION--version check failed";
+		if ( $ENV{VERSION_DEBUG} ) {
+		    require Carp;
+		    Carp::confess($msg);
+		}
+		else {
+		    die($msg);
+		}
+	    }
+
+	    $req = version::vpp->new($req);
+
+	    if ( $req > $version ) {
+		die sprintf ("%s version %s (%s) required--".
+		     "this is only version %s (%s)", $class, 
+		     $req->numify, $req->normal,
+		     $version->numify, $version->normal);
+	    }
+	}
+
+	return defined $version ? $version->numify : undef;
     };
 }
 
